@@ -4,7 +4,7 @@
                   1998-2005 Ivo Timmermans
                   2000-2014 Guus Sliepen <guus@tinc-vpn.org>
                   2010-2011 Julien Muchembled <jm@jmuchemb.eu>
-		  2000 Cris van Pelt
+                  2000 Cris van Pelt
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,18 +28,18 @@
 #include "conf.h"
 #include "list.h"
 #include "logger.h"
-#include "netutl.h"				/* for str2address */
+#include "netutl.h"                             /* for str2address */
 #include "protocol.h"
-#include "utils.h"				/* for cp */
+#include "utils.h"                              /* for cp */
 #include "xalloc.h"
 
 avl_tree_t *config_tree;
 
-int pinginterval = 0;			/* seconds between pings */
-int pingtimeout = 0;			/* seconds to wait for response */
-char *confbase = NULL;			/* directory in which all config files are */
-char *netname = NULL;			/* name of the vpn network */
-list_t *cmdline_conf = NULL;	/* global/host configuration values given at the command line */
+int pinginterval = 0;                   /* seconds between pings */
+int pingtimeout = 0;                    /* seconds to wait for response */
+char *confbase = NULL;                  /* directory in which all config files are */
+char *netname = NULL;                   /* name of the vpn network */
+list_t *cmdline_conf = NULL;    /* global/host configuration values given at the command line */
 
 
 static int config_compare(const config_t *a, const config_t *b) {
@@ -47,27 +47,31 @@ static int config_compare(const config_t *a, const config_t *b) {
 
 	result = strcasecmp(a->variable, b->variable);
 
-	if(result)
+	if(result) {
 		return result;
+	}
 
 	/* give priority to command line options */
 	result = !b->file - !a->file;
-	if (result)
+
+	if(result) {
 		return result;
+	}
 
 	result = a->line - b->line;
 
-	if(result)
+	if(result) {
 		return result;
-	else
+	} else {
 		return a->file ? strcmp(a->file, b->file) : 0;
+	}
 }
 
-void init_configuration(avl_tree_t ** config_tree) {
+void init_configuration(avl_tree_t **config_tree) {
 	*config_tree = avl_alloc_tree((avl_compare_t) config_compare, (avl_action_t) free_config);
 }
 
-void exit_configuration(avl_tree_t ** config_tree) {
+void exit_configuration(avl_tree_t **config_tree) {
 	avl_delete_tree(*config_tree);
 	*config_tree = NULL;
 }
@@ -77,14 +81,17 @@ config_t *new_config(void) {
 }
 
 void free_config(config_t *cfg) {
-	if(cfg->variable)
+	if(cfg->variable) {
 		free(cfg->variable);
+	}
 
-	if(cfg->value)
+	if(cfg->value) {
 		free(cfg->value);
+	}
 
-	if(cfg->file)
+	if(cfg->file) {
 		free(cfg->file);
+	}
 
 	free(cfg);
 }
@@ -102,11 +109,13 @@ config_t *lookup_config(const avl_tree_t *config_tree, char *variable) {
 
 	found = avl_search_closest_greater(config_tree, &cfg);
 
-	if(!found)
+	if(!found) {
 		return NULL;
+	}
 
-	if(strcasecmp(found->variable, variable))
+	if(strcasecmp(found->variable, variable)) {
 		return NULL;
+	}
 
 	return found;
 }
@@ -121,8 +130,9 @@ config_t *lookup_config_next(const avl_tree_t *config_tree, const config_t *cfg)
 		if(node->next) {
 			found = node->next->data;
 
-			if(!strcasecmp(found->variable, cfg->variable))
+			if(!strcasecmp(found->variable, cfg->variable)) {
 				return found;
+			}
 		}
 	}
 
@@ -130,8 +140,9 @@ config_t *lookup_config_next(const avl_tree_t *config_tree, const config_t *cfg)
 }
 
 bool get_config_bool(const config_t *cfg, bool *result) {
-	if(!cfg)
+	if(!cfg) {
 		return false;
+	}
 
 	if(!strcasecmp(cfg->value, "yes")) {
 		*result = true;
@@ -142,27 +153,30 @@ bool get_config_bool(const config_t *cfg, bool *result) {
 	}
 
 	logger(LOG_ERR, "\"yes\" or \"no\" expected for configuration variable %s in %s line %d",
-		   cfg->variable, cfg->file, cfg->line);
+	       cfg->variable, cfg->file, cfg->line);
 
 	return false;
 }
 
 bool get_config_int(const config_t *cfg, int *result) {
-	if(!cfg)
+	if(!cfg) {
 		return false;
+	}
 
-	if(sscanf(cfg->value, "%d", result) == 1)
+	if(sscanf(cfg->value, "%d", result) == 1) {
 		return true;
+	}
 
 	logger(LOG_ERR, "Integer expected for configuration variable %s in %s line %d",
-		   cfg->variable, cfg->file, cfg->line);
+	       cfg->variable, cfg->file, cfg->line);
 
 	return false;
 }
 
 bool get_config_string(const config_t *cfg, char **result) {
-	if(!cfg)
+	if(!cfg) {
 		return false;
+	}
 
 	*result = xstrdup(cfg->value);
 
@@ -172,8 +186,9 @@ bool get_config_string(const config_t *cfg, char **result) {
 bool get_config_address(const config_t *cfg, struct addrinfo **result) {
 	struct addrinfo *ai;
 
-	if(!cfg)
+	if(!cfg) {
 		return false;
+	}
 
 	ai = str2addrinfo(cfg->value, NULL, 0);
 
@@ -183,31 +198,32 @@ bool get_config_address(const config_t *cfg, struct addrinfo **result) {
 	}
 
 	logger(LOG_ERR, "Hostname or IP address expected for configuration variable %s in %s line %d",
-		   cfg->variable, cfg->file, cfg->line);
+	       cfg->variable, cfg->file, cfg->line);
 
 	return false;
 }
 
-bool get_config_subnet(const config_t *cfg, subnet_t ** result) {
-	subnet_t subnet = {NULL};
+bool get_config_subnet(const config_t *cfg, subnet_t **result) {
+	subnet_t subnet = {};
 
-	if(!cfg)
+	if(!cfg) {
 		return false;
+	}
 
 	if(!str2net(&subnet, cfg->value)) {
 		logger(LOG_ERR, "Subnet expected for configuration variable %s in %s line %d",
-			   cfg->variable, cfg->file, cfg->line);
+		       cfg->variable, cfg->file, cfg->line);
 		return false;
 	}
 
 	/* Teach newbies what subnets are... */
 
 	if(((subnet.type == SUBNET_IPV4)
-		&& !maskcheck(&subnet.net.ipv4.address, subnet.net.ipv4.prefixlength, sizeof(ipv4_t)))
-		|| ((subnet.type == SUBNET_IPV6)
-		&& !maskcheck(&subnet.net.ipv6.address, subnet.net.ipv6.prefixlength, sizeof(ipv6_t)))) {
+	                && !maskcheck(&subnet.net.ipv4.address, subnet.net.ipv4.prefixlength, sizeof(ipv4_t)))
+	                || ((subnet.type == SUBNET_IPV6)
+	                    && !maskcheck(&subnet.net.ipv6.address, subnet.net.ipv6.prefixlength, sizeof(ipv6_t)))) {
 		logger(LOG_ERR, "Network address and prefix length do not match for configuration variable %s in %s line %d",
-			   cfg->variable, cfg->file, cfg->line);
+		       cfg->variable, cfg->file, cfg->line);
 		return false;
 	}
 
@@ -219,26 +235,31 @@ bool get_config_subnet(const config_t *cfg, subnet_t ** result) {
 /*
   Read exactly one line and strip the trailing newline if any.
 */
-static char *readline(FILE * fp, char *buf, size_t buflen) {
+static char *readline(FILE *fp, char *buf, size_t buflen) {
 	char *newline = NULL;
 	char *p;
 
-	if(feof(fp))
+	if(feof(fp)) {
 		return NULL;
+	}
 
 	p = fgets(buf, buflen, fp);
 
-	if(!p)
+	if(!p) {
 		return NULL;
+	}
 
 	newline = strchr(p, '\n');
 
-	if(!newline)
+	if(!newline) {
 		return buf;
+	}
 
-	*newline = '\0';	/* kill newline */
-	if(newline > p && newline[-1] == '\r')	/* and carriage return if necessary */
+	*newline = '\0';        /* kill newline */
+
+	if(newline > p && newline[-1] == '\r') { /* and carriage return if necessary */
 		newline[-1] = '\0';
+	}
 
 	return buf;
 }
@@ -250,26 +271,32 @@ config_t *parse_config_line(char *line, const char *fname, int lineno) {
 	variable = value = line;
 
 	eol = line + strlen(line);
-	while(strchr("\t ", *--eol))
+
+	while(strchr("\t ", *--eol)) {
 		*eol = '\0';
+	}
 
 	len = strcspn(value, "\t =");
 	value += len;
 	value += strspn(value, "\t ");
+
 	if(*value == '=') {
 		value++;
 		value += strspn(value, "\t ");
 	}
+
 	variable[len] = '\0';
 
 	if(!*value) {
 		const char err[] = "No value for variable";
-		if (fname)
+
+		if(fname)
 			logger(LOG_ERR, "%s `%s' on line %d while reading config file %s",
-				err, variable, lineno, fname);
+			       err, variable, lineno, fname);
 		else
 			logger(LOG_ERR, "%s `%s' in command line option %d",
-				err, variable, lineno);
+			       err, variable, lineno);
+
 		return NULL;
 	}
 
@@ -303,33 +330,41 @@ bool read_config_file(avl_tree_t *config_tree, const char *fname) {
 	}
 
 	for(;;) {
-		line = readline(fp, buffer, sizeof buffer);
+		line = readline(fp, buffer, sizeof(buffer));
 
 		if(!line) {
-			if(feof(fp))
+			if(feof(fp)) {
 				result = true;
+			}
+
 			break;
 		}
 
 		lineno++;
 
-		if(!*line || *line == '#')
-			continue;
-
-		if(ignore) {
-			if(!strncmp(line, "-----END", 8))
-				ignore = false;
+		if(!*line || *line == '#') {
 			continue;
 		}
-		
+
+		if(ignore) {
+			if(!strncmp(line, "-----END", 8)) {
+				ignore = false;
+			}
+
+			continue;
+		}
+
 		if(!strncmp(line, "-----BEGIN", 10)) {
 			ignore = true;
 			continue;
 		}
 
 		cfg = parse_config_line(line, fname, lineno);
-		if (!cfg)
+
+		if(!cfg) {
 			break;
+		}
+
 		config_add(config_tree, cfg);
 	}
 
@@ -339,86 +374,88 @@ bool read_config_file(avl_tree_t *config_tree, const char *fname) {
 }
 
 void read_config_options(avl_tree_t *config_tree, const char *prefix) {
-	list_node_t *node, *next;
 	size_t prefix_len = prefix ? strlen(prefix) : 0;
 
-	for(node = cmdline_conf->tail; node; node = next) {
-		config_t *orig_cfg, *cfg = (config_t *)node->data;
-		next = node->prev;
+	for(const list_node_t *node = cmdline_conf->tail; node; node = node->prev) {
+		const config_t *cfg = node->data;
 
 		if(!prefix) {
-			if(strchr(cfg->variable, '.'))
+			if(strchr(cfg->variable, '.')) {
 				continue;
-			node->data = NULL;
-			list_unlink_node(cmdline_conf, node);
+			}
 		} else {
 			if(strncmp(prefix, cfg->variable, prefix_len) ||
-			   cfg->variable[prefix_len] != '.')
+			                cfg->variable[prefix_len] != '.') {
 				continue;
-			/* Because host configuration is parsed again when
-			   reconnecting, nodes must not be freed when a prefix
-			   is given. */
-			orig_cfg = cfg;
-			cfg = new_config();
-			cfg->variable = xstrdup(orig_cfg->variable + prefix_len + 1);
-			cfg->value = xstrdup(orig_cfg->value);
-			cfg->file = NULL;
-			cfg->line = orig_cfg->line;
+			}
 		}
-		config_add(config_tree, cfg);
+
+		config_t *new = new_config();
+
+		if(prefix) {
+			new->variable = xstrdup(cfg->variable + prefix_len + 1);
+		} else {
+			new->variable = xstrdup(cfg->variable);
+		}
+
+		new->value = xstrdup(cfg->value);
+		new->file = NULL;
+		new->line = cfg->line;
+
+		config_add(config_tree, new);
 	}
 }
 
 bool read_server_config(void) {
-	char *fname;
+	char fname[PATH_MAX];
 	bool x;
 
 	read_config_options(config_tree, NULL);
 
-	xasprintf(&fname, "%s/tinc.conf", confbase);
+	snprintf(fname, sizeof(fname), "%s/tinc.conf", confbase);
+	errno = 0;
 	x = read_config_file(config_tree, fname);
 
 	// We will try to read the conf files in the "conf.d" dir
-	if (x) {
-		char * dname;
-		xasprintf(&dname, "%s/conf.d", confbase);
-		DIR *dir = opendir (dname);
+	if(x) {
+		char dname[PATH_MAX];
+		snprintf(dname, sizeof(dname), "%s/conf.d", confbase);
+		DIR *dir = opendir(dname);
+
 		// If we can find this dir
-		if (dir) { 
+		if(dir) {
 			struct dirent *ep;
+
 			// We list all the files in it
-			while (x && (ep = readdir (dir))) {
+			while(x && (ep = readdir(dir))) {
 				size_t l = strlen(ep->d_name);
+
 				// And we try to read the ones that end with ".conf"
-				if (l > 5 && !strcmp(".conf", & ep->d_name[ l - 5 ])) {
-					free(fname);
-					xasprintf(&fname, "%s/%s", dname, ep->d_name);
+				if(l > 5 && !strcmp(".conf", & ep->d_name[ l - 5 ])) {
+					snprintf(fname, sizeof(fname), "%s/%s", dname, ep->d_name);
 					x = read_config_file(config_tree, fname);
 				}
 			}
-			closedir (dir);
+
+			closedir(dir);
 		}
-		free(dname);
 	}
 
-	if(!x) {				/* System error: complain */
+	if(!x && errno) {
 		logger(LOG_ERR, "Failed to read `%s': %s", fname, strerror(errno));
 	}
 
-	free(fname);
-
 	return x;
 }
 
 bool read_connection_config(connection_t *c) {
-	char *fname;
+	char fname[PATH_MAX];
 	bool x;
 
 	read_config_options(c->config_tree, c->name);
 
-	xasprintf(&fname, "%s/hosts/%s", confbase, c->name);
+	snprintf(fname, sizeof(fname), "%s/hosts/%s", confbase, c->name);
 	x = read_config_file(c->config_tree, fname);
-	free(fname);
 
 	return x;
 }
@@ -430,34 +467,38 @@ static void disable_old_keys(const char *filename) {
 	FILE *r, *w;
 
 	r = fopen(filename, "r");
-	if(!r)
-		return;
 
-	snprintf(tmpfile, sizeof tmpfile, "%s.tmp", filename);
+	if(!r) {
+		return;
+	}
+
+	snprintf(tmpfile, sizeof(tmpfile), "%s.tmp", filename);
 
 	w = fopen(tmpfile, "w");
 
-	while(fgets(buf, sizeof buf, r)) {
-		if(!strncmp(buf, "-----BEGIN RSA", 14)) {	
+	while(fgets(buf, sizeof(buf), r)) {
+		if(!strncmp(buf, "-----BEGIN RSA", 14)) {
 			buf[11] = 'O';
 			buf[12] = 'L';
 			buf[13] = 'D';
 			disabled = true;
-		}
-		else if(!strncmp(buf, "-----END RSA", 12)) {	
+		} else if(!strncmp(buf, "-----END RSA", 12)) {
 			buf[ 9] = 'O';
 			buf[10] = 'L';
 			buf[11] = 'D';
 			disabled = true;
 		}
+
 		if(w && fputs(buf, w) < 0) {
 			disabled = false;
 			break;
 		}
 	}
 
-	if(w)
+	if(w) {
 		fclose(w);
+	}
+
 	fclose(r);
 
 	if(!w && disabled) {
@@ -469,10 +510,12 @@ static void disable_old_keys(const char *filename) {
 #ifdef HAVE_MINGW
 		// We cannot atomically replace files on Windows.
 		char bakfile[PATH_MAX] = "";
-		snprintf(bakfile, sizeof bakfile, "%s.bak", filename);
+		snprintf(bakfile, sizeof(bakfile), "%s.bak", filename);
+
 		if(rename(filename, bakfile) || rename(tmpfile, filename)) {
 			rename(bakfile, filename);
 #else
+
 		if(rename(tmpfile, filename)) {
 #endif
 			fprintf(stderr, "Warning: old key(s) found, remove them by hand!\n");
@@ -489,8 +532,9 @@ static void disable_old_keys(const char *filename) {
 
 FILE *ask_and_open(const char *filename, const char *what) {
 	FILE *r;
-	char *directory;
+	char directory[PATH_MAX];
 	char line[PATH_MAX];
+	char abspath[PATH_MAX];
 	const char *fn;
 
 	/* Check stdin and stdout */
@@ -502,37 +546,38 @@ FILE *ask_and_open(const char *filename, const char *what) {
 	} else {
 		/* Ask for a file and/or directory name. */
 		fprintf(stdout, "Please enter a file to save %s to [%s]: ",
-				what, filename);
+		        what, filename);
 		fflush(stdout);
 
-		fn = readline(stdin, line, sizeof line);
+		fn = readline(stdin, line, sizeof(line));
 
 		if(!fn) {
 			fprintf(stderr, "Error while reading stdin: %s\n",
-					strerror(errno));
+			        strerror(errno));
 			return NULL;
 		}
 
 		if(!strlen(fn))
 			/* User just pressed enter. */
+		{
 			fn = filename;
+		}
 	}
 
 #ifdef HAVE_MINGW
+
 	if(fn[0] != '\\' && fn[0] != '/' && !strchr(fn, ':')) {
 #else
+
 	if(fn[0] != '/') {
 #endif
 		/* The directory is a relative path or a filename. */
-		char *p;
-
-		directory = get_current_dir_name();
-		xasprintf(&p, "%s/%s", directory, fn);
-		free(directory);
-		fn = p;
+		getcwd(directory, sizeof(directory));
+		snprintf(abspath, sizeof(abspath), "%s/%s", directory, fn);
+		fn = abspath;
 	}
 
-	umask(0077);				/* Disallow everything for group and other */
+	umask(0077);                            /* Disallow everything for group and other */
 
 	disable_old_keys(fn);
 
@@ -542,7 +587,7 @@ FILE *ask_and_open(const char *filename, const char *what) {
 
 	if(!r) {
 		fprintf(stderr, "Error opening file `%s': %s\n",
-				fn, strerror(errno));
+		        fn, strerror(errno));
 		return NULL;
 	}
 
