@@ -16,39 +16,48 @@
 
 #if !HAVE_DECL_GETNAMEINFO
 
-int getnameinfo(const struct sockaddr *sa, size_t salen, char *host, size_t hostlen, char *serv, size_t servlen, int flags)
-{
+int getnameinfo(const struct sockaddr *sa, size_t salen, char *host, size_t hostlen, char *serv, size_t servlen, int flags) {
 	struct sockaddr_in *sin = (struct sockaddr_in *)sa;
 	struct hostent *hp;
 	int len;
 
-	if(sa->sa_family != AF_INET)
+	if(sa->sa_family != AF_INET) {
 		return EAI_FAMILY;
+	}
 
 	if(serv && servlen) {
 		len = snprintf(serv, servlen, "%d", ntohs(sin->sin_port));
-		if(len < 0 || len >= servlen)
+
+		if(len < 0 || len >= servlen) {
 			return EAI_MEMORY;
+		}
 	}
 
-	if(!host || !hostlen)
+	if(!host || !hostlen) {
 		return 0;
+	}
 
 	if(flags & NI_NUMERICHOST) {
 		len = snprintf(host, hostlen, "%s", inet_ntoa(sin->sin_addr));
-		if(len < 0 || len >= hostlen)
+
+		if(len < 0 || len >= hostlen) {
 			return EAI_MEMORY;
+		}
+
 		return 0;
 	}
 
 	hp = gethostbyaddr((char *)&sin->sin_addr, sizeof(struct in_addr), AF_INET);
-	
-	if(!hp || !hp->h_name || !hp->h_name[0])
+
+	if(!hp || !hp->h_name || !hp->h_name[0]) {
 		return EAI_NODATA;
-	
+	}
+
 	len = snprintf(host, hostlen, "%s", hp->h_name);
-	if(len < 0 || len >= hostlen)
+
+	if(len < 0 || len >= hostlen) {
 		return EAI_MEMORY;
+	}
 
 	return 0;
 }
