@@ -1,3 +1,6 @@
+#ifndef TINC_META_H
+#define TINC_META_H
+
 /*
     meta.h -- header for meta.c
     Copyright (C) 2000-2006 Guus Sliepen <guus@tinc-vpn.org>,
@@ -18,14 +21,11 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
-#ifndef __TINC_META_H__
-#define __TINC_META_H__
-
 #include "connection.h"
 
-extern bool send_meta(struct connection_t *, const char *, int);
-extern void broadcast_meta(struct connection_t *, const char *, int);
-extern bool flush_meta(struct connection_t *);
-extern bool receive_meta(struct connection_t *);
+extern bool send_meta(struct connection_t *c, const char *buffer, int length);
+extern void broadcast_meta(struct connection_t *c, const char *buffer, int length);
+extern bool flush_meta(struct connection_t *c);
+extern bool receive_meta(struct connection_t *c);
 
-#endif							/* __TINC_META_H__ */
+#endif
