@@ -1,3 +1,6 @@
+#ifndef TINC_PROXY_H
+#define TINC_PROXY_H
+
 /*
     proxy.h -- header for proxy.c
     Copyright (C) 2015 Guus Sliepen <guus@tinc-vpn.org>
@@ -17,9 +20,6 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
-#ifndef __TINC_PROXY_H__
-#define __TINC_PROXY_H__
-
 #include "connection.h"
 
 typedef enum proxytype_t {
@@ -38,6 +38,6 @@ extern char *proxyuser;
 extern char *proxypass;
 
 extern bool send_proxyrequest(struct connection_t *c);
-extern int receive_proxy_meta(struct connection_t *c, int start, int lenin);
+extern int receive_proxy_meta(struct connection_t *c);
 
 #endif
